==> TencentNavKitDocument_7.1.1.zip: TencentNavKitDocument/search/properties_0.js <==
var searchData=
[
  ['accompanyroutecolorconfig_0',['accompanyRouteColorConfig',['../interface_t_n_k_route_config.html#ae1572a7e0e4060e4ff691f17953717df',1,'TNKRouteConfig']]],
  ['action_1',['action',['../interface_t_n_k_segment_item.html#a2ee4bc0aeb1b4cf1e33323c9feb59124',1,'TNKSegmentItem']]],
  ['adcode_2',['adcode',['../interface_t_n_k_segment_item.html#a4310a53805b5cb909e24341b4e60547d',1,'TNKSegmentItem']]],
  ['adsorbtype_3',['adsorbType',['../interface_t_n_k_search_nav_point.html#a71bb7d7a515c63cf76381180cfd3a422',1,'TNKSearchNavPoint']]],
  ['always_4',['always',['../interface_t_n_k_turn_restriction_item.html#af46e0a9891ce7847a2e86209970994c8',1,'TNKTurnRestrictionItem']]],
  ['arrowcolor_5',['arrowColor',['../interface_t_n_k_turn_arrow_config.html#a2dbe3329dd1b9f020133134bb389c727',1,'TNKTurnArrowConfig']]],
  ['audioplayer_6',['audioPlayer',['../interface_t_n_k_base_nav_manager.html#af6a19911eb68781dc1bb3e1af3428da8',1,'TNKBaseNavManager']]],
  ['autoscaleenabled_7',['autoScaleEnabled',['../interface_t_n_k_drive_nav_view.html#a3a151e0fd96f60933edefedc7356ab3e',1,'TNKDriveNavView']]],
  ['autoscaleminzoomlevel_8',['autoScaleMinZoomLevel',['../interface_t_n_k_drive_nav_view.html#a2b11df3832ce781471acfa5d6b0d842b',1,'TNKDriveNavView']]],
  ['averagespeed_9',['averageSpeed',['../interface_t_n_k_speed_monitor_status.html#a69a906117314df8ea422576dd494e497',1,'TNKSpeedMonitorStatus']]],
  ['avoidhighway_10',['avoidHighway',['../interface_t_n_k_drive_route_search_option.html#aba22b262e9e85edb469e61407f9892da',1,'TNKDriveRouteSearchOption::avoidHighway()'],['../interface_t_n_k_search_preference_reroute_param.html#a726f9d0011dde78529d9169487b52b4c',1,'TNKSearchPreferenceRerouteParam::avoidHighway()']]],
  ['avoidlimit_11',['avoidLimit',['../interface_t_n_k_drive_route_search_option.html#ad089072c343d1cf82fc289c78d958437',1,'TNKDriveRouteSearchOption']]],
  ['avoidtoll_12',['avoidToll',['../interface_t_n_k_drive_route_search_option.html#aecbf226771a7f5602b5ffd5c09cbcd1c',1,'TNKDriveRouteSearchOption::avoidToll()'],['../interface_t_n_k_search_preference_reroute_param.html#a7e6492b6a62de2cd6f00c7fa84fa9ebe',1,'TNKSearchPreferenceRerouteParam::avoidToll()']]],
  ['avoidtrafficjam_13',['avoidTrafficJam',['../interface_t_n_k_drive_route_search_option.html#a6d6641908a62cd449c4f9945e15d697b',1,'TNKDriveRouteSearchOption::avoidTrafficJam()'],['../interface_t_n_k_search_preference_reroute_param.html#ade5bf0c46297b6e1629592f43d11fe81',1,'TNKSearchPreferenceRerouteParam::avoidTrafficJam()']]],
  ['axiscount_14',['axisCount',['../interface_t_n_k_truck_search_option.html#ac23d4146ff847795daf39a1a2b58c607',1,'TNKTruckSearchOption']]],
  ['axisload_15',['axisLoad',['../interface_t_n_k_truck_search_option.html#ae3701a730ac4493689fc5d6eb0e1bedd',1,'TNKTruckSearchOption']]]
];

==> TencentNavKitDocument_7.2.0.zip: TencentNavKitDocument/search/properties_0.js <==
var searchData=
[
  ['accompanyroutecolorconfig_0',['accompanyRouteColorConfig',['../interface_t_n_k_route_config.html#ae1572a7e0e4060e4ff691f17953717df',1,'TNKRouteConfig']]],
  ['action_1',['action',['../interface_t_n_k_segment_item.html#a2ee4bc0aeb1b4cf1e33323c9feb59124',1,'TNKSegmentItem']]],
  ['adcode_2',['adcode',['../interface_t_n_k_segment_item.html#a4310a53805b5cb909e24341b4e60547d',1,'TNKSegmentItem']]],
  ['adsorbtype_3',['adsorbType',['../interface_t_n_k_search_nav_point.html#a71bb7d7a515c63cf76381180cfd3a422',1,'TNKSearchNavPoint']]],
  ['always_4',['always',['../interface_t_n_k_turn_restriction_item.html#af46e0a9891ce7847a2e86209970994c8',1,'TNKTurnRestrictionItem']]],
  ['arrowcolor_5',['arrowColor',['../interface_t_n_k_turn_arrow_config.html#a2dbe3329dd1b9f020133134bb389c727',1,'TNKTurnArrowConfig']]],
  ['audioplayer_6',['audioPlayer',['../interface_t_n_k_base_nav_manager.html#af6a19911eb68781dc1bb3e1af3428da8',1,'TNKBaseNavManager']]],
  ['autoscaleenabled_7',['autoScaleEnabled',['../interface_t_n_k_drive_nav_view.html#a3a151e0fd96f60933edefedc7356ab3e',1,'TNKDriveNavView::autoScaleEnabled()'],['../interface_t_n_k_travel_nav_view.html#a6046cfcb9fc666efa5269224c06ff96f',1,'TNKTravelNavView::autoScaleEnabled()']]],
  ['autoscaleminzoomlevel_8',['autoScaleMinZoomLevel',['../interface_t_n_k_drive_nav_view.html#a2b11df3832ce781471acfa5d6b0d842b',1,'TNKDriveNavView::autoScaleMinZoomLevel()'],['../interface_t_n_k_travel_nav_view.html#ab9b7ad39efb61641066d86d043a18540',1,'TNKTravelNavView::autoScaleMinZoomLevel()']]],
  ['averagespeed_9',['averageSpeed',['../interface_t_n_k_speed_monitor_status.html#a69a906117314df8ea422576dd494e497',1,'TNKSpeedMonitorStatus']]],
  ['avoidhighway_10',['avoidHighway',['../interface_t_n_k_drive_route_search_option.html#aba22b262e9e85edb469e61407f9892da',1,'TNKDriveRouteSearchOption::avoidHighway()'],['../interface_t_n_k_search_preference_reroute_param.html#a726f9d0011dde78529d9169487b52b4c',1,'TNKSearchPreferenceRerouteParam::avoidHighway()']]],
  ['avoidlimit_11',['avoidLimit',['../interface_t_n_k_drive_route_search_option.html#ad089072c343d1cf82fc289c78d958437',1,'TNKDriveRouteSearchOption']]],
  ['avoidtoll_12',['avoidToll',['../interface_t_n_k_drive_route_search_option.html#aecbf226771a7f5602b5ffd5c09cbcd1c',1,'TNKDriveRouteSearchOption::avoidToll()'],['../interface_t_n_k_search_preference_reroute_param.html#a7e6492b6a62de2cd6f00c7fa84fa9ebe',1,'TNKSearchPreferenceRerouteParam::avoidToll()']]],
  ['avoidtrafficjam_13',['avoidTrafficJam',['../interface_t_n_k_drive_route_search_option.html#a6d6641908a62cd449c4f9945e15d697b',1,'TNKDriveRouteSearchOption::avoidTrafficJam()'],['../interface_t_n_k_search_preference_reroute_param.html#ade5bf0c46297b6e1629592f43d11fe81',1,'TNKSearchPreferenceRerouteParam::avoidTrafficJam()']]],
  ['axiscount_14',['axisCount',['../interface_t_n_k_truck_search_option.html#ac23d4146ff847795daf39a1a2b58c607',1,'TNKTruckSearchOption']]],
  ['axisload_15',['axisLoad',['../interface_t_n_k_truck_search_option.html#ae3701a730ac4493689fc5d6eb0e1bedd',1,'TNKTruckSearchOption']]]
];
